# PyCozo

Python client and Jupyter helper for [CozoDB](https://github.com/cozodb/cozo).

To install:

```bash
pip install "pycozo[pandas]"
```

More detailed instructions are [here](https://cozodb.github.io/current/manual/setup.html#jupyterlab).